[![PyPI version](https://badge.fury.io/py/genetest.svg)](http://badge.fury.io/py/genetest)
[![Build Status](https://travis-ci.org/pgxcentre/genetest.svg?branch=master)](https://travis-ci.org/pgxcentre/genetest)


# genetest - A Python module for statistical genetics

The `genetest` module includes a script that will perform various statistical
analysis on genetics data (*e.g.* hard calls, imputed data, etc.).


## Dependencies

The tool requires a standard [Python](http://python.org/) installation (3.4 or
higher are supported) with the following modules:

1. [numpy](http://www.numpy.org/) version 1.12 or latest
2. [pandas](http://pandas.pydata.org/) version 0.19 or latest
3. [stasmodels](http://statsmodels.sourceforge.net/stable/index.html) version 0.8 or latest
4. [grako](https://github.com/swayf/grako) version 3.10 or latest
5. [geneparse](https://github.com/pgxcentre/geneparse) version 0.1 or latest

The tool has been tested on *Linux* only, but should work on *MacOS* operating
systems as well.


## Documentation

Documentation is available at http://pgxcentre.github.io/genetest/.


## Installation

Using `pip`:

```bash
pip install genetest
```


### Updating

To update the module using `pip`:

```bash
pip install -U genetest
```


## Testing

To test the module, just perform the following command:

```console
$ python -m genetest.tests
...
----------------------------------------------------------------------
Ran 104 tests in 1.684s

OK (skipped=41, expected failures=1)
```
